# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.standard_media_info import StandardMediaInfo
from bitmovin_api_sdk.models.video_media_info import VideoMediaInfo
from bitmovin_api_sdk.encoding.manifests.hls.media.video.video_media_info_list_query_params import VideoMediaInfoListQueryParams


class VideoApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(VideoApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, video_media_info, **kwargs):
        # type: (string_types, VideoMediaInfo, dict) -> VideoMediaInfo
        """Add Video Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param video_media_info: The Video Media to be added
        :type video_media_info: VideoMediaInfo, required
        :return: Video media details
        :rtype: VideoMediaInfo
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/media/video',
            video_media_info,
            path_params={'manifest_id': manifest_id},
            type=VideoMediaInfo,
            **kwargs
        )

    def delete(self, manifest_id, media_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Video Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param media_id: Id of the video media.
        :type media_id: string_types, required
        :return: Id of the video media
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/hls/{manifest_id}/media/video/{media_id}',
            path_params={'manifest_id': manifest_id, 'media_id': media_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, media_id, **kwargs):
        # type: (string_types, string_types, dict) -> VideoMediaInfo
        """Video Media Details

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param media_id: Id of the video media.
        :type media_id: string_types, required
        :return: Video media details
        :rtype: VideoMediaInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/media/video/{media_id}',
            path_params={'manifest_id': manifest_id, 'media_id': media_id},
            type=VideoMediaInfo,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, VideoMediaInfoListQueryParams, dict) -> VideoMediaInfo
        """List all Video Media

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: VideoMediaInfoListQueryParams
        :return: Video media
        :rtype: VideoMediaInfo
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/media/video',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=VideoMediaInfo,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_error import ResponseError


class StartApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StartApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def update(self, stream_id, **kwargs):
        # type: (string_types, dict) -> None
        """Start live stream by id

        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        """

        self.api_client.put(
            '/streams/live/{stream_id}/start',
            path_params={'stream_id': stream_id},
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AudioVideoSyncMode(Enum):
    STANDARD = "STANDARD"
    RESYNC_AT_START = "RESYNC_AT_START"
    RESYNC_AT_START_AND_END = "RESYNC_AT_START_AND_END"



from bitmovin_api_sdk.encoding.manifests.hls.media.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.manifests.hls.media.subtitles.subtitles_media_info_list_query_params import SubtitlesMediaInfoListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SrtStatisticLink(object):
    @poscheck_model
    def __init__(self,
                 bandwidth=None,
                 max_bandwidth=None,
                 rtt=None):
        # type: (float, float, float) -> None

        self._bandwidth = None
        self._max_bandwidth = None
        self._rtt = None
        self.discriminator = None

        if bandwidth is not None:
            self.bandwidth = bandwidth
        if max_bandwidth is not None:
            self.max_bandwidth = max_bandwidth
        if rtt is not None:
            self.rtt = rtt

    @property
    def openapi_types(self):
        types = {
            'bandwidth': 'float',
            'max_bandwidth': 'float',
            'rtt': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'bandwidth': 'bandwidth',
            'max_bandwidth': 'maxBandwidth',
            'rtt': 'rtt'
        }
        return attributes

    @property
    def bandwidth(self):
        # type: () -> float
        """Gets the bandwidth of this SrtStatisticLink.


        :return: The bandwidth of this SrtStatisticLink.
        :rtype: float
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        # type: (float) -> None
        """Sets the bandwidth of this SrtStatisticLink.


        :param bandwidth: The bandwidth of this SrtStatisticLink.
        :type: float
        """

        if bandwidth is not None:
            if not isinstance(bandwidth, (float, int)):
                raise TypeError("Invalid type for `bandwidth`, type has to be `float`")

        self._bandwidth = bandwidth

    @property
    def max_bandwidth(self):
        # type: () -> float
        """Gets the max_bandwidth of this SrtStatisticLink.


        :return: The max_bandwidth of this SrtStatisticLink.
        :rtype: float
        """
        return self._max_bandwidth

    @max_bandwidth.setter
    def max_bandwidth(self, max_bandwidth):
        # type: (float) -> None
        """Sets the max_bandwidth of this SrtStatisticLink.


        :param max_bandwidth: The max_bandwidth of this SrtStatisticLink.
        :type: float
        """

        if max_bandwidth is not None:
            if not isinstance(max_bandwidth, (float, int)):
                raise TypeError("Invalid type for `max_bandwidth`, type has to be `float`")

        self._max_bandwidth = max_bandwidth

    @property
    def rtt(self):
        # type: () -> float
        """Gets the rtt of this SrtStatisticLink.


        :return: The rtt of this SrtStatisticLink.
        :rtype: float
        """
        return self._rtt

    @rtt.setter
    def rtt(self, rtt):
        # type: (float) -> None
        """Sets the rtt of this SrtStatisticLink.


        :param rtt: The rtt of this SrtStatisticLink.
        :type: float
        """

        if rtt is not None:
            if not isinstance(rtt, (float, int)):
                raise TypeError("Invalid type for `rtt`, type has to be `float`")

        self._rtt = rtt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtStatisticLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamSelectionMode(Enum):
    AUTO = "AUTO"
    POSITION_ABSOLUTE = "POSITION_ABSOLUTE"
    VIDEO_RELATIVE = "VIDEO_RELATIVE"
    AUDIO_RELATIVE = "AUDIO_RELATIVE"
    SUBTITLE_RELATIVE = "SUBTITLE_RELATIVE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class InsertableContentStatus(Enum):
    CREATED = "CREATED"
    DOWNLOADING = "DOWNLOADING"
    READY = "READY"
    ERROR = "ERROR"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.clear_key_drm import ClearKeyDrm
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.clearkey.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.clearkey.clear_key_drm_list_query_params import ClearKeyDrmListQueryParams


class ClearkeyApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ClearkeyApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, muxing_id, clear_key_drm, **kwargs):
        # type: (string_types, string_types, ClearKeyDrm, dict) -> ClearKeyDrm
        """Add ClearKey DRM to an fMP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the fMP4 muxing.
        :type muxing_id: string_types, required
        :param clear_key_drm: The ClearKey DRM to be created
        :type clear_key_drm: ClearKeyDrm, required
        :return: ClearKey configuration
        :rtype: ClearKeyDrm
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/fmp4/{muxing_id}/drm/clearkey',
            clear_key_drm,
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=ClearKeyDrm,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete ClearKey DRM from an fMP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the fMP4 muxing
        :type muxing_id: string_types, required
        :param drm_id: Id of the ClearKey DRM configuration.
        :type drm_id: string_types, required
        :return: Id of the ClearKey DRM configuration.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/fmp4/{muxing_id}/drm/clearkey/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> ClearKeyDrm
        """ClearKey DRM Details of an fMP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the fMP4 muxing
        :type muxing_id: string_types, required
        :param drm_id: Id of the ClearKey DRM configuration.
        :type drm_id: string_types, required
        :return: ClearKey configuration
        :rtype: ClearKeyDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/fmp4/{muxing_id}/drm/clearkey/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=ClearKeyDrm,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, query_params=None, **kwargs):
        # type: (string_types, string_types, ClearKeyDrmListQueryParams, dict) -> ClearKeyDrm
        """List ClearKey DRMs of an fMP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the fMP4 muxing
        :type muxing_id: string_types, required
        :param query_params: Query parameters
        :type query_params: ClearKeyDrmListQueryParams
        :return: List of ClearKey DRM configurations
        :rtype: ClearKeyDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/fmp4/{muxing_id}/drm/clearkey',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            query_params=query_params,
            pagination_response=True,
            type=ClearKeyDrm,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.codec_config_type import CodecConfigType
from bitmovin_api_sdk.models.dolby_vision_per_stream_mode import DolbyVisionPerStreamMode
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.input_factor import InputFactor
from bitmovin_api_sdk.models.nex_guard_ab_watermarking_feature import NexGuardABWatermarkingFeature
from bitmovin_api_sdk.models.pixel_format_bit_depth import PixelFormatBitDepth
from bitmovin_api_sdk.models.psnr_per_stream_mode import PsnrPerStreamMode
from bitmovin_api_sdk.models.statistics_per_title_stream import StatisticsPerTitleStream
from bitmovin_api_sdk.models.statistics_resolution import StatisticsResolution
import pprint
import six


class StatisticsPerStream(object):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 codec_config_id=None,
                 multiplicator=None,
                 encoded_bytes=None,
                 encoded_seconds=None,
                 billable_minutes=None,
                 width=None,
                 height=None,
                 rate=None,
                 bitrate=None,
                 codec=None,
                 resolution=None,
                 encoding_mode=None,
                 encoding_mode_multiplicator=None,
                 per_title_result_stream=None,
                 per_title_multiplicator=None,
                 psnr_mode=None,
                 psnr_multiplicator=None,
                 dolby_vision_mode=None,
                 dolby_vision_multiplicator=None,
                 preset=None,
                 preset_multiplicator=None,
                 live=None,
                 live_multiplicator=None,
                 enhanced_deinterlace=None,
                 enhanced_deinterlace_multiplicator=None,
                 dolby_vision_to_hdr=None,
                 dolby_vision_to_hdr_multiplicator=None,
                 dolby_vision_to_sdr=None,
                 dolby_vision_to_sdr_multiplicator=None,
                 hdr_hlg_to_sdr=None,
                 hdr_hlg_to_sdr_multiplicator=None,
                 nex_guard_ab_watermarking_type=None,
                 nex_guard_ab_watermarking_multiplicator=None,
                 pixel_format_bit_depth=None,
                 pixel_format_multiplicator=None,
                 input_factor=None):
        # type: (string_types, string_types, float, int, float, float, int, int, float, int, CodecConfigType, StatisticsResolution, EncodingMode, float, StatisticsPerTitleStream, float, PsnrPerStreamMode, float, DolbyVisionPerStreamMode, float, string_types, float, bool, float, bool, float, bool, float, bool, float, bool, float, NexGuardABWatermarkingFeature, float, PixelFormatBitDepth, float, InputFactor) -> None

        self._stream_id = None
        self._codec_config_id = None
        self._multiplicator = None
        self._encoded_bytes = None
        self._encoded_seconds = None
        self._billable_minutes = None
        self._width = None
        self._height = None
        self._rate = None
        self._bitrate = None
        self._codec = None
        self._resolution = None
        self._encoding_mode = None
        self._encoding_mode_multiplicator = None
        self._per_title_result_stream = None
        self._per_title_multiplicator = None
        self._psnr_mode = None
        self._psnr_multiplicator = None
        self._dolby_vision_mode = None
        self._dolby_vision_multiplicator = None
        self._preset = None
        self._preset_multiplicator = None
        self._live = None
        self._live_multiplicator = None
        self._enhanced_deinterlace = None
        self._enhanced_deinterlace_multiplicator = None
        self._dolby_vision_to_hdr = None
        self._dolby_vision_to_hdr_multiplicator = None
        self._dolby_vision_to_sdr = None
        self._dolby_vision_to_sdr_multiplicator = None
        self._hdr_hlg_to_sdr = None
        self._hdr_hlg_to_sdr_multiplicator = None
        self._nex_guard_ab_watermarking_type = None
        self._nex_guard_ab_watermarking_multiplicator = None
        self._pixel_format_bit_depth = None
        self._pixel_format_multiplicator = None
        self._input_factor = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if codec_config_id is not None:
            self.codec_config_id = codec_config_id
        if multiplicator is not None:
            self.multiplicator = multiplicator
        if encoded_bytes is not None:
            self.encoded_bytes = encoded_bytes
        if encoded_seconds is not None:
            self.encoded_seconds = encoded_seconds
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if rate is not None:
            self.rate = rate
        if bitrate is not None:
            self.bitrate = bitrate
        if codec is not None:
            self.codec = codec
        if resolution is not None:
            self.resolution = resolution
        if encoding_mode is not None:
            self.encoding_mode = encoding_mode
        if encoding_mode_multiplicator is not None:
            self.encoding_mode_multiplicator = encoding_mode_multiplicator
        if per_title_result_stream is not None:
            self.per_title_result_stream = per_title_result_stream
        if per_title_multiplicator is not None:
            self.per_title_multiplicator = per_title_multiplicator
        if psnr_mode is not None:
            self.psnr_mode = psnr_mode
        if psnr_multiplicator is not None:
            self.psnr_multiplicator = psnr_multiplicator
        if dolby_vision_mode is not None:
            self.dolby_vision_mode = dolby_vision_mode
        if dolby_vision_multiplicator is not None:
            self.dolby_vision_multiplicator = dolby_vision_multiplicator
        if preset is not None:
            self.preset = preset
        if preset_multiplicator is not None:
            self.preset_multiplicator = preset_multiplicator
        if live is not None:
            self.live = live
        if live_multiplicator is not None:
            self.live_multiplicator = live_multiplicator
        if enhanced_deinterlace is not None:
            self.enhanced_deinterlace = enhanced_deinterlace
        if enhanced_deinterlace_multiplicator is not None:
            self.enhanced_deinterlace_multiplicator = enhanced_deinterlace_multiplicator
        if dolby_vision_to_hdr is not None:
            self.dolby_vision_to_hdr = dolby_vision_to_hdr
        if dolby_vision_to_hdr_multiplicator is not None:
            self.dolby_vision_to_hdr_multiplicator = dolby_vision_to_hdr_multiplicator
        if dolby_vision_to_sdr is not None:
            self.dolby_vision_to_sdr = dolby_vision_to_sdr
        if dolby_vision_to_sdr_multiplicator is not None:
            self.dolby_vision_to_sdr_multiplicator = dolby_vision_to_sdr_multiplicator
        if hdr_hlg_to_sdr is not None:
            self.hdr_hlg_to_sdr = hdr_hlg_to_sdr
        if hdr_hlg_to_sdr_multiplicator is not None:
            self.hdr_hlg_to_sdr_multiplicator = hdr_hlg_to_sdr_multiplicator
        if nex_guard_ab_watermarking_type is not None:
            self.nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type
        if nex_guard_ab_watermarking_multiplicator is not None:
            self.nex_guard_ab_watermarking_multiplicator = nex_guard_ab_watermarking_multiplicator
        if pixel_format_bit_depth is not None:
            self.pixel_format_bit_depth = pixel_format_bit_depth
        if pixel_format_multiplicator is not None:
            self.pixel_format_multiplicator = pixel_format_multiplicator
        if input_factor is not None:
            self.input_factor = input_factor

    @property
    def openapi_types(self):
        types = {
            'stream_id': 'string_types',
            'codec_config_id': 'string_types',
            'multiplicator': 'float',
            'encoded_bytes': 'int',
            'encoded_seconds': 'float',
            'billable_minutes': 'float',
            'width': 'int',
            'height': 'int',
            'rate': 'float',
            'bitrate': 'int',
            'codec': 'CodecConfigType',
            'resolution': 'StatisticsResolution',
            'encoding_mode': 'EncodingMode',
            'encoding_mode_multiplicator': 'float',
            'per_title_result_stream': 'StatisticsPerTitleStream',
            'per_title_multiplicator': 'float',
            'psnr_mode': 'PsnrPerStreamMode',
            'psnr_multiplicator': 'float',
            'dolby_vision_mode': 'DolbyVisionPerStreamMode',
            'dolby_vision_multiplicator': 'float',
            'preset': 'string_types',
            'preset_multiplicator': 'float',
            'live': 'bool',
            'live_multiplicator': 'float',
            'enhanced_deinterlace': 'bool',
            'enhanced_deinterlace_multiplicator': 'float',
            'dolby_vision_to_hdr': 'bool',
            'dolby_vision_to_hdr_multiplicator': 'float',
            'dolby_vision_to_sdr': 'bool',
            'dolby_vision_to_sdr_multiplicator': 'float',
            'hdr_hlg_to_sdr': 'bool',
            'hdr_hlg_to_sdr_multiplicator': 'float',
            'nex_guard_ab_watermarking_type': 'NexGuardABWatermarkingFeature',
            'nex_guard_ab_watermarking_multiplicator': 'float',
            'pixel_format_bit_depth': 'PixelFormatBitDepth',
            'pixel_format_multiplicator': 'float',
            'input_factor': 'InputFactor'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_id': 'streamId',
            'codec_config_id': 'codecConfigId',
            'multiplicator': 'multiplicator',
            'encoded_bytes': 'encodedBytes',
            'encoded_seconds': 'encodedSeconds',
            'billable_minutes': 'billableMinutes',
            'width': 'width',
            'height': 'height',
            'rate': 'rate',
            'bitrate': 'bitrate',
            'codec': 'codec',
            'resolution': 'resolution',
            'encoding_mode': 'encodingMode',
            'encoding_mode_multiplicator': 'encodingModeMultiplicator',
            'per_title_result_stream': 'perTitleResultStream',
            'per_title_multiplicator': 'perTitleMultiplicator',
            'psnr_mode': 'psnrMode',
            'psnr_multiplicator': 'psnrMultiplicator',
            'dolby_vision_mode': 'dolbyVisionMode',
            'dolby_vision_multiplicator': 'dolbyVisionMultiplicator',
            'preset': 'preset',
            'preset_multiplicator': 'presetMultiplicator',
            'live': 'live',
            'live_multiplicator': 'liveMultiplicator',
            'enhanced_deinterlace': 'enhancedDeinterlace',
            'enhanced_deinterlace_multiplicator': 'enhancedDeinterlaceMultiplicator',
            'dolby_vision_to_hdr': 'dolbyVisionToHdr',
            'dolby_vision_to_hdr_multiplicator': 'dolbyVisionToHdrMultiplicator',
            'dolby_vision_to_sdr': 'dolbyVisionToSdr',
            'dolby_vision_to_sdr_multiplicator': 'dolbyVisionToSdrMultiplicator',
            'hdr_hlg_to_sdr': 'hdrHlgToSdr',
            'hdr_hlg_to_sdr_multiplicator': 'hdrHlgToSdrMultiplicator',
            'nex_guard_ab_watermarking_type': 'nexGuardABWatermarkingType',
            'nex_guard_ab_watermarking_multiplicator': 'nexGuardABWatermarkingMultiplicator',
            'pixel_format_bit_depth': 'pixelFormatBitDepth',
            'pixel_format_multiplicator': 'pixelFormatMultiplicator',
            'input_factor': 'inputFactor'
        }
        return attributes

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this StatisticsPerStream.

        ID of the stream (required)

        :return: The stream_id of this StatisticsPerStream.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this StatisticsPerStream.

        ID of the stream (required)

        :param stream_id: The stream_id of this StatisticsPerStream.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def codec_config_id(self):
        # type: () -> string_types
        """Gets the codec_config_id of this StatisticsPerStream.

        ID of the condec configuration (required)

        :return: The codec_config_id of this StatisticsPerStream.
        :rtype: string_types
        """
        return self._codec_config_id

    @codec_config_id.setter
    def codec_config_id(self, codec_config_id):
        # type: (string_types) -> None
        """Sets the codec_config_id of this StatisticsPerStream.

        ID of the condec configuration (required)

        :param codec_config_id: The codec_config_id of this StatisticsPerStream.
        :type: string_types
        """

        if codec_config_id is not None:
            if not isinstance(codec_config_id, string_types):
                raise TypeError("Invalid type for `codec_config_id`, type has to be `string_types`")

        self._codec_config_id = codec_config_id

    @property
    def multiplicator(self):
        # type: () -> float
        """Gets the multiplicator of this StatisticsPerStream.

        Multiplier for the encoded minutes. Depends on muxing type. (required)

        :return: The multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._multiplicator

    @multiplicator.setter
    def multiplicator(self, multiplicator):
        # type: (float) -> None
        """Sets the multiplicator of this StatisticsPerStream.

        Multiplier for the encoded minutes. Depends on muxing type. (required)

        :param multiplicator: The multiplicator of this StatisticsPerStream.
        :type: float
        """

        if multiplicator is not None:
            if not isinstance(multiplicator, (float, int)):
                raise TypeError("Invalid type for `multiplicator`, type has to be `float`")

        self._multiplicator = multiplicator

    @property
    def encoded_bytes(self):
        # type: () -> int
        """Gets the encoded_bytes of this StatisticsPerStream.

        Encoded bytes. (required)

        :return: The encoded_bytes of this StatisticsPerStream.
        :rtype: int
        """
        return self._encoded_bytes

    @encoded_bytes.setter
    def encoded_bytes(self, encoded_bytes):
        # type: (int) -> None
        """Sets the encoded_bytes of this StatisticsPerStream.

        Encoded bytes. (required)

        :param encoded_bytes: The encoded_bytes of this StatisticsPerStream.
        :type: int
        """

        if encoded_bytes is not None:
            if not isinstance(encoded_bytes, int):
                raise TypeError("Invalid type for `encoded_bytes`, type has to be `int`")

        self._encoded_bytes = encoded_bytes

    @property
    def encoded_seconds(self):
        # type: () -> float
        """Gets the encoded_seconds of this StatisticsPerStream.

        Length of the stream. (required)

        :return: The encoded_seconds of this StatisticsPerStream.
        :rtype: float
        """
        return self._encoded_seconds

    @encoded_seconds.setter
    def encoded_seconds(self, encoded_seconds):
        # type: (float) -> None
        """Sets the encoded_seconds of this StatisticsPerStream.

        Length of the stream. (required)

        :param encoded_seconds: The encoded_seconds of this StatisticsPerStream.
        :type: float
        """

        if encoded_seconds is not None:
            if not isinstance(encoded_seconds, (float, int)):
                raise TypeError("Invalid type for `encoded_seconds`, type has to be `float`")

        self._encoded_seconds = encoded_seconds

    @property
    def billable_minutes(self):
        # type: () -> float
        """Gets the billable_minutes of this StatisticsPerStream.

        Minutes you will be charged for (billableMinutes = encodedSeconds * multiplicator) (required)

        :return: The billable_minutes of this StatisticsPerStream.
        :rtype: float
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (float) -> None
        """Sets the billable_minutes of this StatisticsPerStream.

        Minutes you will be charged for (billableMinutes = encodedSeconds * multiplicator) (required)

        :param billable_minutes: The billable_minutes of this StatisticsPerStream.
        :type: float
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `float`")

        self._billable_minutes = billable_minutes

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this StatisticsPerStream.

        Video width, only if video stream

        :return: The width of this StatisticsPerStream.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this StatisticsPerStream.

        Video width, only if video stream

        :param width: The width of this StatisticsPerStream.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this StatisticsPerStream.

        Video height, only if video stream

        :return: The height of this StatisticsPerStream.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this StatisticsPerStream.

        Video height, only if video stream

        :param height: The height of this StatisticsPerStream.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def rate(self):
        # type: () -> float
        """Gets the rate of this StatisticsPerStream.

        If it' a video stream this value is the FPS, for audio it's the sample rate. (required)

        :return: The rate of this StatisticsPerStream.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (float) -> None
        """Sets the rate of this StatisticsPerStream.

        If it' a video stream this value is the FPS, for audio it's the sample rate. (required)

        :param rate: The rate of this StatisticsPerStream.
        :type: float
        """

        if rate is not None:
            if not isinstance(rate, (float, int)):
                raise TypeError("Invalid type for `rate`, type has to be `float`")

        self._rate = rate

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this StatisticsPerStream.

        Bitrate of the stream (required)

        :return: The bitrate of this StatisticsPerStream.
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this StatisticsPerStream.

        Bitrate of the stream (required)

        :param bitrate: The bitrate of this StatisticsPerStream.
        :type: int
        """

        if bitrate is not None:
            if not isinstance(bitrate, int):
                raise TypeError("Invalid type for `bitrate`, type has to be `int`")

        self._bitrate = bitrate

    @property
    def codec(self):
        # type: () -> CodecConfigType
        """Gets the codec of this StatisticsPerStream.


        :return: The codec of this StatisticsPerStream.
        :rtype: CodecConfigType
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (CodecConfigType) -> None
        """Sets the codec of this StatisticsPerStream.


        :param codec: The codec of this StatisticsPerStream.
        :type: CodecConfigType
        """

        if codec is not None:
            if not isinstance(codec, CodecConfigType):
                raise TypeError("Invalid type for `codec`, type has to be `CodecConfigType`")

        self._codec = codec

    @property
    def resolution(self):
        # type: () -> StatisticsResolution
        """Gets the resolution of this StatisticsPerStream.


        :return: The resolution of this StatisticsPerStream.
        :rtype: StatisticsResolution
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        # type: (StatisticsResolution) -> None
        """Sets the resolution of this StatisticsPerStream.


        :param resolution: The resolution of this StatisticsPerStream.
        :type: StatisticsResolution
        """

        if resolution is not None:
            if not isinstance(resolution, StatisticsResolution):
                raise TypeError("Invalid type for `resolution`, type has to be `StatisticsResolution`")

        self._resolution = resolution

    @property
    def encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the encoding_mode of this StatisticsPerStream.


        :return: The encoding_mode of this StatisticsPerStream.
        :rtype: EncodingMode
        """
        return self._encoding_mode

    @encoding_mode.setter
    def encoding_mode(self, encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the encoding_mode of this StatisticsPerStream.


        :param encoding_mode: The encoding_mode of this StatisticsPerStream.
        :type: EncodingMode
        """

        if encoding_mode is not None:
            if not isinstance(encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `encoding_mode`, type has to be `EncodingMode`")

        self._encoding_mode = encoding_mode

    @property
    def encoding_mode_multiplicator(self):
        # type: () -> float
        """Gets the encoding_mode_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the given encodingMode

        :return: The encoding_mode_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._encoding_mode_multiplicator

    @encoding_mode_multiplicator.setter
    def encoding_mode_multiplicator(self, encoding_mode_multiplicator):
        # type: (float) -> None
        """Sets the encoding_mode_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the given encodingMode

        :param encoding_mode_multiplicator: The encoding_mode_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if encoding_mode_multiplicator is not None:
            if not isinstance(encoding_mode_multiplicator, (float, int)):
                raise TypeError("Invalid type for `encoding_mode_multiplicator`, type has to be `float`")

        self._encoding_mode_multiplicator = encoding_mode_multiplicator

    @property
    def per_title_result_stream(self):
        # type: () -> StatisticsPerTitleStream
        """Gets the per_title_result_stream of this StatisticsPerStream.


        :return: The per_title_result_stream of this StatisticsPerStream.
        :rtype: StatisticsPerTitleStream
        """
        return self._per_title_result_stream

    @per_title_result_stream.setter
    def per_title_result_stream(self, per_title_result_stream):
        # type: (StatisticsPerTitleStream) -> None
        """Sets the per_title_result_stream of this StatisticsPerStream.


        :param per_title_result_stream: The per_title_result_stream of this StatisticsPerStream.
        :type: StatisticsPerTitleStream
        """

        if per_title_result_stream is not None:
            if not isinstance(per_title_result_stream, StatisticsPerTitleStream):
                raise TypeError("Invalid type for `per_title_result_stream`, type has to be `StatisticsPerTitleStream`")

        self._per_title_result_stream = per_title_result_stream

    @property
    def per_title_multiplicator(self):
        # type: () -> float
        """Gets the per_title_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for per-title

        :return: The per_title_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._per_title_multiplicator

    @per_title_multiplicator.setter
    def per_title_multiplicator(self, per_title_multiplicator):
        # type: (float) -> None
        """Sets the per_title_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for per-title

        :param per_title_multiplicator: The per_title_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if per_title_multiplicator is not None:
            if not isinstance(per_title_multiplicator, (float, int)):
                raise TypeError("Invalid type for `per_title_multiplicator`, type has to be `float`")

        self._per_title_multiplicator = per_title_multiplicator

    @property
    def psnr_mode(self):
        # type: () -> PsnrPerStreamMode
        """Gets the psnr_mode of this StatisticsPerStream.


        :return: The psnr_mode of this StatisticsPerStream.
        :rtype: PsnrPerStreamMode
        """
        return self._psnr_mode

    @psnr_mode.setter
    def psnr_mode(self, psnr_mode):
        # type: (PsnrPerStreamMode) -> None
        """Sets the psnr_mode of this StatisticsPerStream.


        :param psnr_mode: The psnr_mode of this StatisticsPerStream.
        :type: PsnrPerStreamMode
        """

        if psnr_mode is not None:
            if not isinstance(psnr_mode, PsnrPerStreamMode):
                raise TypeError("Invalid type for `psnr_mode`, type has to be `PsnrPerStreamMode`")

        self._psnr_mode = psnr_mode

    @property
    def psnr_multiplicator(self):
        # type: () -> float
        """Gets the psnr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for psnr streams

        :return: The psnr_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._psnr_multiplicator

    @psnr_multiplicator.setter
    def psnr_multiplicator(self, psnr_multiplicator):
        # type: (float) -> None
        """Sets the psnr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for psnr streams

        :param psnr_multiplicator: The psnr_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if psnr_multiplicator is not None:
            if not isinstance(psnr_multiplicator, (float, int)):
                raise TypeError("Invalid type for `psnr_multiplicator`, type has to be `float`")

        self._psnr_multiplicator = psnr_multiplicator

    @property
    def dolby_vision_mode(self):
        # type: () -> DolbyVisionPerStreamMode
        """Gets the dolby_vision_mode of this StatisticsPerStream.


        :return: The dolby_vision_mode of this StatisticsPerStream.
        :rtype: DolbyVisionPerStreamMode
        """
        return self._dolby_vision_mode

    @dolby_vision_mode.setter
    def dolby_vision_mode(self, dolby_vision_mode):
        # type: (DolbyVisionPerStreamMode) -> None
        """Sets the dolby_vision_mode of this StatisticsPerStream.


        :param dolby_vision_mode: The dolby_vision_mode of this StatisticsPerStream.
        :type: DolbyVisionPerStreamMode
        """

        if dolby_vision_mode is not None:
            if not isinstance(dolby_vision_mode, DolbyVisionPerStreamMode):
                raise TypeError("Invalid type for `dolby_vision_mode`, type has to be `DolbyVisionPerStreamMode`")

        self._dolby_vision_mode = dolby_vision_mode

    @property
    def dolby_vision_multiplicator(self):
        # type: () -> float
        """Gets the dolby_vision_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for Dolby Vision streams

        :return: The dolby_vision_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._dolby_vision_multiplicator

    @dolby_vision_multiplicator.setter
    def dolby_vision_multiplicator(self, dolby_vision_multiplicator):
        # type: (float) -> None
        """Sets the dolby_vision_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for Dolby Vision streams

        :param dolby_vision_multiplicator: The dolby_vision_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if dolby_vision_multiplicator is not None:
            if not isinstance(dolby_vision_multiplicator, (float, int)):
                raise TypeError("Invalid type for `dolby_vision_multiplicator`, type has to be `float`")

        self._dolby_vision_multiplicator = dolby_vision_multiplicator

    @property
    def preset(self):
        # type: () -> string_types
        """Gets the preset of this StatisticsPerStream.

        Name of the preset configuration used for the codec configuration or \"CUSTOM\" if any preset values were overridden

        :return: The preset of this StatisticsPerStream.
        :rtype: string_types
        """
        return self._preset

    @preset.setter
    def preset(self, preset):
        # type: (string_types) -> None
        """Sets the preset of this StatisticsPerStream.

        Name of the preset configuration used for the codec configuration or \"CUSTOM\" if any preset values were overridden

        :param preset: The preset of this StatisticsPerStream.
        :type: string_types
        """

        if preset is not None:
            if not isinstance(preset, string_types):
                raise TypeError("Invalid type for `preset`, type has to be `string_types`")

        self._preset = preset

    @property
    def preset_multiplicator(self):
        # type: () -> float
        """Gets the preset_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the used codec configuration preset.

        :return: The preset_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._preset_multiplicator

    @preset_multiplicator.setter
    def preset_multiplicator(self, preset_multiplicator):
        # type: (float) -> None
        """Sets the preset_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the used codec configuration preset.

        :param preset_multiplicator: The preset_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if preset_multiplicator is not None:
            if not isinstance(preset_multiplicator, (float, int)):
                raise TypeError("Invalid type for `preset_multiplicator`, type has to be `float`")

        self._preset_multiplicator = preset_multiplicator

    @property
    def live(self):
        # type: () -> bool
        """Gets the live of this StatisticsPerStream.

        Indicates if the stream was part of a live encoding.

        :return: The live of this StatisticsPerStream.
        :rtype: bool
        """
        return self._live

    @live.setter
    def live(self, live):
        # type: (bool) -> None
        """Sets the live of this StatisticsPerStream.

        Indicates if the stream was part of a live encoding.

        :param live: The live of this StatisticsPerStream.
        :type: bool
        """

        if live is not None:
            if not isinstance(live, bool):
                raise TypeError("Invalid type for `live`, type has to be `bool`")

        self._live = live

    @property
    def live_multiplicator(self):
        # type: () -> float
        """Gets the live_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for live streams.

        :return: The live_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._live_multiplicator

    @live_multiplicator.setter
    def live_multiplicator(self, live_multiplicator):
        # type: (float) -> None
        """Sets the live_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for live streams.

        :param live_multiplicator: The live_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if live_multiplicator is not None:
            if not isinstance(live_multiplicator, (float, int)):
                raise TypeError("Invalid type for `live_multiplicator`, type has to be `float`")

        self._live_multiplicator = live_multiplicator

    @property
    def enhanced_deinterlace(self):
        # type: () -> bool
        """Gets the enhanced_deinterlace of this StatisticsPerStream.

        Indicates if an enhanced interlace filter was used.

        :return: The enhanced_deinterlace of this StatisticsPerStream.
        :rtype: bool
        """
        return self._enhanced_deinterlace

    @enhanced_deinterlace.setter
    def enhanced_deinterlace(self, enhanced_deinterlace):
        # type: (bool) -> None
        """Sets the enhanced_deinterlace of this StatisticsPerStream.

        Indicates if an enhanced interlace filter was used.

        :param enhanced_deinterlace: The enhanced_deinterlace of this StatisticsPerStream.
        :type: bool
        """

        if enhanced_deinterlace is not None:
            if not isinstance(enhanced_deinterlace, bool):
                raise TypeError("Invalid type for `enhanced_deinterlace`, type has to be `bool`")

        self._enhanced_deinterlace = enhanced_deinterlace

    @property
    def enhanced_deinterlace_multiplicator(self):
        # type: () -> float
        """Gets the enhanced_deinterlace_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using an enhanced Deinterlace Filter.

        :return: The enhanced_deinterlace_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._enhanced_deinterlace_multiplicator

    @enhanced_deinterlace_multiplicator.setter
    def enhanced_deinterlace_multiplicator(self, enhanced_deinterlace_multiplicator):
        # type: (float) -> None
        """Sets the enhanced_deinterlace_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using an enhanced Deinterlace Filter.

        :param enhanced_deinterlace_multiplicator: The enhanced_deinterlace_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if enhanced_deinterlace_multiplicator is not None:
            if not isinstance(enhanced_deinterlace_multiplicator, (float, int)):
                raise TypeError("Invalid type for `enhanced_deinterlace_multiplicator`, type has to be `float`")

        self._enhanced_deinterlace_multiplicator = enhanced_deinterlace_multiplicator

    @property
    def dolby_vision_to_hdr(self):
        # type: () -> bool
        """Gets the dolby_vision_to_hdr of this StatisticsPerStream.

        Indicates if the conversion from Dolby Vision to HDR was triggered.

        :return: The dolby_vision_to_hdr of this StatisticsPerStream.
        :rtype: bool
        """
        return self._dolby_vision_to_hdr

    @dolby_vision_to_hdr.setter
    def dolby_vision_to_hdr(self, dolby_vision_to_hdr):
        # type: (bool) -> None
        """Sets the dolby_vision_to_hdr of this StatisticsPerStream.

        Indicates if the conversion from Dolby Vision to HDR was triggered.

        :param dolby_vision_to_hdr: The dolby_vision_to_hdr of this StatisticsPerStream.
        :type: bool
        """

        if dolby_vision_to_hdr is not None:
            if not isinstance(dolby_vision_to_hdr, bool):
                raise TypeError("Invalid type for `dolby_vision_to_hdr`, type has to be `bool`")

        self._dolby_vision_to_hdr = dolby_vision_to_hdr

    @property
    def dolby_vision_to_hdr_multiplicator(self):
        # type: () -> float
        """Gets the dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from Dolby Vision to HDR.

        :return: The dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._dolby_vision_to_hdr_multiplicator

    @dolby_vision_to_hdr_multiplicator.setter
    def dolby_vision_to_hdr_multiplicator(self, dolby_vision_to_hdr_multiplicator):
        # type: (float) -> None
        """Sets the dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from Dolby Vision to HDR.

        :param dolby_vision_to_hdr_multiplicator: The dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if dolby_vision_to_hdr_multiplicator is not None:
            if not isinstance(dolby_vision_to_hdr_multiplicator, (float, int)):
                raise TypeError("Invalid type for `dolby_vision_to_hdr_multiplicator`, type has to be `float`")

        self._dolby_vision_to_hdr_multiplicator = dolby_vision_to_hdr_multiplicator

    @property
    def dolby_vision_to_sdr(self):
        # type: () -> bool
        """Gets the dolby_vision_to_sdr of this StatisticsPerStream.

        Indicates if the conversion from Dolby Vision to SDR was triggered.

        :return: The dolby_vision_to_sdr of this StatisticsPerStream.
        :rtype: bool
        """
        return self._dolby_vision_to_sdr

    @dolby_vision_to_sdr.setter
    def dolby_vision_to_sdr(self, dolby_vision_to_sdr):
        # type: (bool) -> None
        """Sets the dolby_vision_to_sdr of this StatisticsPerStream.

        Indicates if the conversion from Dolby Vision to SDR was triggered.

        :param dolby_vision_to_sdr: The dolby_vision_to_sdr of this StatisticsPerStream.
        :type: bool
        """

        if dolby_vision_to_sdr is not None:
            if not isinstance(dolby_vision_to_sdr, bool):
                raise TypeError("Invalid type for `dolby_vision_to_sdr`, type has to be `bool`")

        self._dolby_vision_to_sdr = dolby_vision_to_sdr

    @property
    def dolby_vision_to_sdr_multiplicator(self):
        # type: () -> float
        """Gets the dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from Dolby Vision to SDR.

        :return: The dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._dolby_vision_to_sdr_multiplicator

    @dolby_vision_to_sdr_multiplicator.setter
    def dolby_vision_to_sdr_multiplicator(self, dolby_vision_to_sdr_multiplicator):
        # type: (float) -> None
        """Sets the dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from Dolby Vision to SDR.

        :param dolby_vision_to_sdr_multiplicator: The dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if dolby_vision_to_sdr_multiplicator is not None:
            if not isinstance(dolby_vision_to_sdr_multiplicator, (float, int)):
                raise TypeError("Invalid type for `dolby_vision_to_sdr_multiplicator`, type has to be `float`")

        self._dolby_vision_to_sdr_multiplicator = dolby_vision_to_sdr_multiplicator

    @property
    def hdr_hlg_to_sdr(self):
        # type: () -> bool
        """Gets the hdr_hlg_to_sdr of this StatisticsPerStream.

        Indicates if the conversion from HDR10/HLG to SDR was triggered.

        :return: The hdr_hlg_to_sdr of this StatisticsPerStream.
        :rtype: bool
        """
        return self._hdr_hlg_to_sdr

    @hdr_hlg_to_sdr.setter
    def hdr_hlg_to_sdr(self, hdr_hlg_to_sdr):
        # type: (bool) -> None
        """Sets the hdr_hlg_to_sdr of this StatisticsPerStream.

        Indicates if the conversion from HDR10/HLG to SDR was triggered.

        :param hdr_hlg_to_sdr: The hdr_hlg_to_sdr of this StatisticsPerStream.
        :type: bool
        """

        if hdr_hlg_to_sdr is not None:
            if not isinstance(hdr_hlg_to_sdr, bool):
                raise TypeError("Invalid type for `hdr_hlg_to_sdr`, type has to be `bool`")

        self._hdr_hlg_to_sdr = hdr_hlg_to_sdr

    @property
    def hdr_hlg_to_sdr_multiplicator(self):
        # type: () -> float
        """Gets the hdr_hlg_to_sdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from HDR10/HLG to SDR.

        :return: The hdr_hlg_to_sdr_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._hdr_hlg_to_sdr_multiplicator

    @hdr_hlg_to_sdr_multiplicator.setter
    def hdr_hlg_to_sdr_multiplicator(self, hdr_hlg_to_sdr_multiplicator):
        # type: (float) -> None
        """Sets the hdr_hlg_to_sdr_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using the conversion from HDR10/HLG to SDR.

        :param hdr_hlg_to_sdr_multiplicator: The hdr_hlg_to_sdr_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if hdr_hlg_to_sdr_multiplicator is not None:
            if not isinstance(hdr_hlg_to_sdr_multiplicator, (float, int)):
                raise TypeError("Invalid type for `hdr_hlg_to_sdr_multiplicator`, type has to be `float`")

        self._hdr_hlg_to_sdr_multiplicator = hdr_hlg_to_sdr_multiplicator

    @property
    def nex_guard_ab_watermarking_type(self):
        # type: () -> NexGuardABWatermarkingFeature
        """Gets the nex_guard_ab_watermarking_type of this StatisticsPerStream.


        :return: The nex_guard_ab_watermarking_type of this StatisticsPerStream.
        :rtype: NexGuardABWatermarkingFeature
        """
        return self._nex_guard_ab_watermarking_type

    @nex_guard_ab_watermarking_type.setter
    def nex_guard_ab_watermarking_type(self, nex_guard_ab_watermarking_type):
        # type: (NexGuardABWatermarkingFeature) -> None
        """Sets the nex_guard_ab_watermarking_type of this StatisticsPerStream.


        :param nex_guard_ab_watermarking_type: The nex_guard_ab_watermarking_type of this StatisticsPerStream.
        :type: NexGuardABWatermarkingFeature
        """

        if nex_guard_ab_watermarking_type is not None:
            if not isinstance(nex_guard_ab_watermarking_type, NexGuardABWatermarkingFeature):
                raise TypeError("Invalid type for `nex_guard_ab_watermarking_type`, type has to be `NexGuardABWatermarkingFeature`")

        self._nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type

    @property
    def nex_guard_ab_watermarking_multiplicator(self):
        # type: () -> float
        """Gets the nex_guard_ab_watermarking_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using a NexGuard A/B Watermarking.

        :return: The nex_guard_ab_watermarking_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._nex_guard_ab_watermarking_multiplicator

    @nex_guard_ab_watermarking_multiplicator.setter
    def nex_guard_ab_watermarking_multiplicator(self, nex_guard_ab_watermarking_multiplicator):
        # type: (float) -> None
        """Sets the nex_guard_ab_watermarking_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for streams using a NexGuard A/B Watermarking.

        :param nex_guard_ab_watermarking_multiplicator: The nex_guard_ab_watermarking_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if nex_guard_ab_watermarking_multiplicator is not None:
            if not isinstance(nex_guard_ab_watermarking_multiplicator, (float, int)):
                raise TypeError("Invalid type for `nex_guard_ab_watermarking_multiplicator`, type has to be `float`")

        self._nex_guard_ab_watermarking_multiplicator = nex_guard_ab_watermarking_multiplicator

    @property
    def pixel_format_bit_depth(self):
        # type: () -> PixelFormatBitDepth
        """Gets the pixel_format_bit_depth of this StatisticsPerStream.


        :return: The pixel_format_bit_depth of this StatisticsPerStream.
        :rtype: PixelFormatBitDepth
        """
        return self._pixel_format_bit_depth

    @pixel_format_bit_depth.setter
    def pixel_format_bit_depth(self, pixel_format_bit_depth):
        # type: (PixelFormatBitDepth) -> None
        """Sets the pixel_format_bit_depth of this StatisticsPerStream.


        :param pixel_format_bit_depth: The pixel_format_bit_depth of this StatisticsPerStream.
        :type: PixelFormatBitDepth
        """

        if pixel_format_bit_depth is not None:
            if not isinstance(pixel_format_bit_depth, PixelFormatBitDepth):
                raise TypeError("Invalid type for `pixel_format_bit_depth`, type has to be `PixelFormatBitDepth`")

        self._pixel_format_bit_depth = pixel_format_bit_depth

    @property
    def pixel_format_multiplicator(self):
        # type: () -> float
        """Gets the pixel_format_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the pixel format bit depth

        :return: The pixel_format_multiplicator of this StatisticsPerStream.
        :rtype: float
        """
        return self._pixel_format_multiplicator

    @pixel_format_multiplicator.setter
    def pixel_format_multiplicator(self, pixel_format_multiplicator):
        # type: (float) -> None
        """Sets the pixel_format_multiplicator of this StatisticsPerStream.

        The output minutes multiplicator for the pixel format bit depth

        :param pixel_format_multiplicator: The pixel_format_multiplicator of this StatisticsPerStream.
        :type: float
        """

        if pixel_format_multiplicator is not None:
            if not isinstance(pixel_format_multiplicator, (float, int)):
                raise TypeError("Invalid type for `pixel_format_multiplicator`, type has to be `float`")

        self._pixel_format_multiplicator = pixel_format_multiplicator

    @property
    def input_factor(self):
        # type: () -> InputFactor
        """Gets the input_factor of this StatisticsPerStream.


        :return: The input_factor of this StatisticsPerStream.
        :rtype: InputFactor
        """
        return self._input_factor

    @input_factor.setter
    def input_factor(self, input_factor):
        # type: (InputFactor) -> None
        """Sets the input_factor of this StatisticsPerStream.


        :param input_factor: The input_factor of this StatisticsPerStream.
        :type: InputFactor
        """

        if input_factor is not None:
            if not isinstance(input_factor, InputFactor):
                raise TypeError("Invalid type for `input_factor`, type has to be `InputFactor`")

        self._input_factor = input_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticsPerStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.per_title_fixed_resolution_and_bitrate_configuration_mode import PerTitleFixedResolutionAndBitrateConfigurationMode
import pprint
import six


class PerTitleFixedResolutionAndBitrateConfiguration(object):
    @poscheck_model
    def __init__(self,
                 forced_rendition_above_highest_fixed_representation=None,
                 forced_rendition_above_highest_fixed_representation_factor=None,
                 forced_rendition_above_highest_fixed_representation_calculation_mode=None):
        # type: (int, float, PerTitleFixedResolutionAndBitrateConfigurationMode) -> None

        self._forced_rendition_above_highest_fixed_representation = None
        self._forced_rendition_above_highest_fixed_representation_factor = None
        self._forced_rendition_above_highest_fixed_representation_calculation_mode = None
        self.discriminator = None

        if forced_rendition_above_highest_fixed_representation is not None:
            self.forced_rendition_above_highest_fixed_representation = forced_rendition_above_highest_fixed_representation
        if forced_rendition_above_highest_fixed_representation_factor is not None:
            self.forced_rendition_above_highest_fixed_representation_factor = forced_rendition_above_highest_fixed_representation_factor
        if forced_rendition_above_highest_fixed_representation_calculation_mode is not None:
            self.forced_rendition_above_highest_fixed_representation_calculation_mode = forced_rendition_above_highest_fixed_representation_calculation_mode

    @property
    def openapi_types(self):
        types = {
            'forced_rendition_above_highest_fixed_representation': 'int',
            'forced_rendition_above_highest_fixed_representation_factor': 'float',
            'forced_rendition_above_highest_fixed_representation_calculation_mode': 'PerTitleFixedResolutionAndBitrateConfigurationMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'forced_rendition_above_highest_fixed_representation': 'forcedRenditionAboveHighestFixedRepresentation',
            'forced_rendition_above_highest_fixed_representation_factor': 'forcedRenditionAboveHighestFixedRepresentationFactor',
            'forced_rendition_above_highest_fixed_representation_calculation_mode': 'forcedRenditionAboveHighestFixedRepresentationCalculationMode'
        }
        return attributes

    @property
    def forced_rendition_above_highest_fixed_representation(self):
        # type: () -> int
        """Gets the forced_rendition_above_highest_fixed_representation of this PerTitleFixedResolutionAndBitrateConfiguration.

        Number of forced renditions above the highest fixed representation (e.g. FIXED_RESOLUTION_AND_BITRATE). Forced renditions will be added, also if the Per-Title algorithm chooses the user defined force rendition to be the highest one.

        :return: The forced_rendition_above_highest_fixed_representation of this PerTitleFixedResolutionAndBitrateConfiguration.
        :rtype: int
        """
        return self._forced_rendition_above_highest_fixed_representation

    @forced_rendition_above_highest_fixed_representation.setter
    def forced_rendition_above_highest_fixed_representation(self, forced_rendition_above_highest_fixed_representation):
        # type: (int) -> None
        """Sets the forced_rendition_above_highest_fixed_representation of this PerTitleFixedResolutionAndBitrateConfiguration.

        Number of forced renditions above the highest fixed representation (e.g. FIXED_RESOLUTION_AND_BITRATE). Forced renditions will be added, also if the Per-Title algorithm chooses the user defined force rendition to be the highest one.

        :param forced_rendition_above_highest_fixed_representation: The forced_rendition_above_highest_fixed_representation of this PerTitleFixedResolutionAndBitrateConfiguration.
        :type: int
        """

        if forced_rendition_above_highest_fixed_representation is not None:
            if forced_rendition_above_highest_fixed_representation is not None and forced_rendition_above_highest_fixed_representation < 1:
                raise ValueError("Invalid value for `forced_rendition_above_highest_fixed_representation`, must be a value greater than or equal to `1`")
            if not isinstance(forced_rendition_above_highest_fixed_representation, int):
                raise TypeError("Invalid type for `forced_rendition_above_highest_fixed_representation`, type has to be `int`")

        self._forced_rendition_above_highest_fixed_representation = forced_rendition_above_highest_fixed_representation

    @property
    def forced_rendition_above_highest_fixed_representation_factor(self):
        # type: () -> float
        """Gets the forced_rendition_above_highest_fixed_representation_factor of this PerTitleFixedResolutionAndBitrateConfiguration.

        The factor to calculate the bitrate that will be chosen based on the bitrate of the last FIXED_RESOLUTION.

        :return: The forced_rendition_above_highest_fixed_representation_factor of this PerTitleFixedResolutionAndBitrateConfiguration.
        :rtype: float
        """
        return self._forced_rendition_above_highest_fixed_representation_factor

    @forced_rendition_above_highest_fixed_representation_factor.setter
    def forced_rendition_above_highest_fixed_representation_factor(self, forced_rendition_above_highest_fixed_representation_factor):
        # type: (float) -> None
        """Sets the forced_rendition_above_highest_fixed_representation_factor of this PerTitleFixedResolutionAndBitrateConfiguration.

        The factor to calculate the bitrate that will be chosen based on the bitrate of the last FIXED_RESOLUTION.

        :param forced_rendition_above_highest_fixed_representation_factor: The forced_rendition_above_highest_fixed_representation_factor of this PerTitleFixedResolutionAndBitrateConfiguration.
        :type: float
        """

        if forced_rendition_above_highest_fixed_representation_factor is not None:
            if not isinstance(forced_rendition_above_highest_fixed_representation_factor, (float, int)):
                raise TypeError("Invalid type for `forced_rendition_above_highest_fixed_representation_factor`, type has to be `float`")

        self._forced_rendition_above_highest_fixed_representation_factor = forced_rendition_above_highest_fixed_representation_factor

    @property
    def forced_rendition_above_highest_fixed_representation_calculation_mode(self):
        # type: () -> PerTitleFixedResolutionAndBitrateConfigurationMode
        """Gets the forced_rendition_above_highest_fixed_representation_calculation_mode of this PerTitleFixedResolutionAndBitrateConfiguration.

        Mode to calculate the bitrate of the next representation

        :return: The forced_rendition_above_highest_fixed_representation_calculation_mode of this PerTitleFixedResolutionAndBitrateConfiguration.
        :rtype: PerTitleFixedResolutionAndBitrateConfigurationMode
        """
        return self._forced_rendition_above_highest_fixed_representation_calculation_mode

    @forced_rendition_above_highest_fixed_representation_calculation_mode.setter
    def forced_rendition_above_highest_fixed_representation_calculation_mode(self, forced_rendition_above_highest_fixed_representation_calculation_mode):
        # type: (PerTitleFixedResolutionAndBitrateConfigurationMode) -> None
        """Sets the forced_rendition_above_highest_fixed_representation_calculation_mode of this PerTitleFixedResolutionAndBitrateConfiguration.

        Mode to calculate the bitrate of the next representation

        :param forced_rendition_above_highest_fixed_representation_calculation_mode: The forced_rendition_above_highest_fixed_representation_calculation_mode of this PerTitleFixedResolutionAndBitrateConfiguration.
        :type: PerTitleFixedResolutionAndBitrateConfigurationMode
        """

        if forced_rendition_above_highest_fixed_representation_calculation_mode is not None:
            if not isinstance(forced_rendition_above_highest_fixed_representation_calculation_mode, PerTitleFixedResolutionAndBitrateConfigurationMode):
                raise TypeError("Invalid type for `forced_rendition_above_highest_fixed_representation_calculation_mode`, type has to be `PerTitleFixedResolutionAndBitrateConfigurationMode`")

        self._forced_rendition_above_highest_fixed_representation_calculation_mode = forced_rendition_above_highest_fixed_representation_calculation_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PerTitleFixedResolutionAndBitrateConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class ProgressiveMuxingInformation(object):
    @poscheck_model
    def __init__(self,
                 mime_type=None,
                 file_size=None,
                 container_format=None,
                 container_bitrate=None,
                 duration=None,
                 video_tracks=None,
                 audio_tracks=None):
        # type: (string_types, int, string_types, int, float, list[MuxingInformationVideoTrack], list[MuxingInformationAudioTrack]) -> None

        self._mime_type = None
        self._file_size = None
        self._container_format = None
        self._container_bitrate = None
        self._duration = None
        self._video_tracks = list()
        self._audio_tracks = list()
        self.discriminator = None

        if mime_type is not None:
            self.mime_type = mime_type
        if file_size is not None:
            self.file_size = file_size
        if container_format is not None:
            self.container_format = container_format
        if container_bitrate is not None:
            self.container_bitrate = container_bitrate
        if duration is not None:
            self.duration = duration
        if video_tracks is not None:
            self.video_tracks = video_tracks
        if audio_tracks is not None:
            self.audio_tracks = audio_tracks

    @property
    def openapi_types(self):
        types = {
            'mime_type': 'string_types',
            'file_size': 'int',
            'container_format': 'string_types',
            'container_bitrate': 'int',
            'duration': 'float',
            'video_tracks': 'list[MuxingInformationVideoTrack]',
            'audio_tracks': 'list[MuxingInformationAudioTrack]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'mime_type': 'mimeType',
            'file_size': 'fileSize',
            'container_format': 'containerFormat',
            'container_bitrate': 'containerBitrate',
            'duration': 'duration',
            'video_tracks': 'videoTracks',
            'audio_tracks': 'audioTracks'
        }
        return attributes

    @property
    def mime_type(self):
        # type: () -> string_types
        """Gets the mime_type of this ProgressiveMuxingInformation.

        The mime type of the muxing

        :return: The mime_type of this ProgressiveMuxingInformation.
        :rtype: string_types
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        # type: (string_types) -> None
        """Sets the mime_type of this ProgressiveMuxingInformation.

        The mime type of the muxing

        :param mime_type: The mime_type of this ProgressiveMuxingInformation.
        :type: string_types
        """

        if mime_type is not None:
            if not isinstance(mime_type, string_types):
                raise TypeError("Invalid type for `mime_type`, type has to be `string_types`")

        self._mime_type = mime_type

    @property
    def file_size(self):
        # type: () -> int
        """Gets the file_size of this ProgressiveMuxingInformation.

        The file size of the muxing in bytes

        :return: The file_size of this ProgressiveMuxingInformation.
        :rtype: int
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        # type: (int) -> None
        """Sets the file_size of this ProgressiveMuxingInformation.

        The file size of the muxing in bytes

        :param file_size: The file_size of this ProgressiveMuxingInformation.
        :type: int
        """

        if file_size is not None:
            if not isinstance(file_size, int):
                raise TypeError("Invalid type for `file_size`, type has to be `int`")

        self._file_size = file_size

    @property
    def container_format(self):
        # type: () -> string_types
        """Gets the container_format of this ProgressiveMuxingInformation.

        The container format used

        :return: The container_format of this ProgressiveMuxingInformation.
        :rtype: string_types
        """
        return self._container_format

    @container_format.setter
    def container_format(self, container_format):
        # type: (string_types) -> None
        """Sets the container_format of this ProgressiveMuxingInformation.

        The container format used

        :param container_format: The container_format of this ProgressiveMuxingInformation.
        :type: string_types
        """

        if container_format is not None:
            if not isinstance(container_format, string_types):
                raise TypeError("Invalid type for `container_format`, type has to be `string_types`")

        self._container_format = container_format

    @property
    def container_bitrate(self):
        # type: () -> int
        """Gets the container_bitrate of this ProgressiveMuxingInformation.

        The bitrate of the container if available (tracks + container overhead)

        :return: The container_bitrate of this ProgressiveMuxingInformation.
        :rtype: int
        """
        return self._container_bitrate

    @container_bitrate.setter
    def container_bitrate(self, container_bitrate):
        # type: (int) -> None
        """Sets the container_bitrate of this ProgressiveMuxingInformation.

        The bitrate of the container if available (tracks + container overhead)

        :param container_bitrate: The container_bitrate of this ProgressiveMuxingInformation.
        :type: int
        """

        if container_bitrate is not None:
            if not isinstance(container_bitrate, int):
                raise TypeError("Invalid type for `container_bitrate`, type has to be `int`")

        self._container_bitrate = container_bitrate

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this ProgressiveMuxingInformation.

        The duration of the container in seconds

        :return: The duration of this ProgressiveMuxingInformation.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this ProgressiveMuxingInformation.

        The duration of the container in seconds

        :param duration: The duration of this ProgressiveMuxingInformation.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def video_tracks(self):
        # type: () -> list[MuxingInformationVideoTrack]
        """Gets the video_tracks of this ProgressiveMuxingInformation.

        Information about the video tracks in the container

        :return: The video_tracks of this ProgressiveMuxingInformation.
        :rtype: list[MuxingInformationVideoTrack]
        """
        return self._video_tracks

    @video_tracks.setter
    def video_tracks(self, video_tracks):
        # type: (list) -> None
        """Sets the video_tracks of this ProgressiveMuxingInformation.

        Information about the video tracks in the container

        :param video_tracks: The video_tracks of this ProgressiveMuxingInformation.
        :type: list[MuxingInformationVideoTrack]
        """

        if video_tracks is not None:
            if not isinstance(video_tracks, list):
                raise TypeError("Invalid type for `video_tracks`, type has to be `list[MuxingInformationVideoTrack]`")

        self._video_tracks = video_tracks

    @property
    def audio_tracks(self):
        # type: () -> list[MuxingInformationAudioTrack]
        """Gets the audio_tracks of this ProgressiveMuxingInformation.

        Information about the audio tracks in the container

        :return: The audio_tracks of this ProgressiveMuxingInformation.
        :rtype: list[MuxingInformationAudioTrack]
        """
        return self._audio_tracks

    @audio_tracks.setter
    def audio_tracks(self, audio_tracks):
        # type: (list) -> None
        """Sets the audio_tracks of this ProgressiveMuxingInformation.

        Information about the audio tracks in the container

        :param audio_tracks: The audio_tracks of this ProgressiveMuxingInformation.
        :type: list[MuxingInformationAudioTrack]
        """

        if audio_tracks is not None:
            if not isinstance(audio_tracks, list):
                raise TypeError("Invalid type for `audio_tracks`, type has to be `list[MuxingInformationAudioTrack]`")

        self._audio_tracks = audio_tracks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressiveMuxingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import re
import pytz
import datetime

from enum import Enum
from requests import RequestException
from six.moves import urllib
from six import iteritems

from bitmovin_api_sdk.common.bitmovin_api_logger_base import BitmovinApiLoggerBase
from bitmovin_api_sdk.common.bitmovin_error import BitmovinError
from bitmovin_api_sdk.common.rest_client import RestClient
from bitmovin_api_sdk.common.bitmovin_json_decoder import BitmovinJsonDecoder
from bitmovin_api_sdk.common.poscheck import poscheck, poscheck_except
from bitmovin_api_sdk.models import BitmovinResponse, ResponseErrorData


class ApiClient(object):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        self.rest_client = RestClient(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    @staticmethod
    def _remove_none_values_from_dict(dict_to_remove_from):
        # type: (dict) -> dict

        return dict((k, v) for k, v in dict_to_remove_from.items() if v is not None)

    @staticmethod
    def _check_url_contains_placeholders(url):
        # type: (str) -> bool

        found = re.search(r'({.*})', url)
        return found is not None

    def prepare_url(self, relative_url, query_params=None, **kwargs):
        # type: (str, dict) -> str

        if query_params is not None:
            query_params = self._replace_with_real_names(query_params=query_params)
            query_params = self._remove_none_values_from_dict(query_params)
            values_to_replace = {}

            for k, v in iteritems(query_params):
                if isinstance(v, Enum):
                    values_to_replace[k] = v.value
                if isinstance(v, datetime.datetime):
                    if v.tzinfo is not None and v.tzinfo.utcoffset(v) is not None:
                        values_to_replace[k] = str(v.astimezone(pytz.utc).isoformat()).replace('+00:00', 'Z')
                    else:
                        datetime_tz_aware = v.replace(tzinfo=pytz.utc).astimezone(pytz.utc).isoformat()
                        values_to_replace[k] = str(datetime_tz_aware).replace('+00:00', 'Z')

            for k, v in iteritems(values_to_replace):
                query_params[k] = v

            relative_url += '?' + urllib.parse.urlencode(query_params)

        if not self._check_url_contains_placeholders(relative_url):
            return relative_url

        if 'path_params' not in kwargs:
            raise KeyError('path_params is missing in kwargs')

        path_params = kwargs['path_params']

        if not isinstance(path_params, dict):
            raise TypeError('path_params has to be dict')

        for k in path_params:
            if isinstance(path_params[k], datetime.date) or isinstance(path_params[k], datetime.datetime):
                path_params[k] = path_params[k].isoformat()

            relative_url = relative_url.replace(
                '{%s}' % k,
                path_params[k]
            )

        if self._check_url_contains_placeholders(url=relative_url):
            raise Exception('url {} does contain placeholders after replacing'.format(relative_url))

        return relative_url

    def request(self, method, relative_url, payload=None, raw_response=False, query_params=None, **kwargs):
        # type: (str, str, object, bool, dict) -> object

        url = self.prepare_url(relative_url, query_params=query_params, **kwargs)

        try:
            response = self.rest_client.request(method=method, payload=payload, relative_url=url)
            return response if raw_response else self._map_response_to_model(response, **kwargs)
        except Exception as e:
            complete_url = self.rest_client.urljoin(self.rest_client.base_url, url)
            raise BitmovinError(e=e, http_request_method=method, http_request_url=complete_url, http_request_payload=payload)

    def delete(self, relative_url, **kwargs):
        # type: (str, dict) -> object

        if 'type' not in kwargs or kwargs['type'] is None:
            kwargs['type'] = BitmovinResponse

        return self.request('DELETE', relative_url=relative_url, **kwargs)

    def get(self, relative_url, query_params=None, **kwargs):
        # type: (str, dict) -> object

        raw_response = False
        if 'type' not in kwargs or kwargs['type'] is None:
            raw_response = True

        return self.request('GET', relative_url=relative_url, raw_response=raw_response, query_params=query_params, **kwargs)

    def post(self, relative_url, payload=None, **kwargs):
        # type: (str, object, dict) -> object

        if 'type' not in kwargs or kwargs['type'] is None:
            raise KeyError('type must be given in kwargs')

        if payload is not None:
            if type(payload) != list:
                payload_dict = payload.to_dict()
                return self.request('POST', relative_url=relative_url, payload=payload_dict, **kwargs)
            else:
                return self.request('POST', relative_url=relative_url, payload=payload, **kwargs)
        elif payload is None:
            return self.request('POST', relative_url=relative_url, **kwargs)

    def put(self, relative_url, payload, **kwargs):
        # type: (str, object, dict) -> object

        if 'type' not in kwargs or kwargs['type'] is None:
            raise KeyError('type must be given in kwargs')

        payload_dict = payload.to_dict()

        return self.request('PUT', relative_url=relative_url, payload=payload_dict if payload else None, **kwargs)

    @staticmethod
    def _map_response_to_model(response, **kwargs):
        # type: (dict, dict) -> object

        if 'status' in response and response['status'] == 'SUCCESS':
            if 'data' in response and 'result' in response['data']:
                response_success = response['data']['result']
                if 'pagination_response' in kwargs and kwargs['pagination_response']:
                    return BitmovinJsonDecoder.map_dict_to_pagination_response(response_success, kwargs['type'])
                elif 'list_response' in kwargs and kwargs['list_response']:
                    return BitmovinJsonDecoder.map_dict_to_list(response_success, kwargs['type'])
                else:
                    return BitmovinJsonDecoder.map_dict_to_model(response_success, kwargs['type'])
            else:
                return BitmovinJsonDecoder.map_dict_to_model(response['data'], kwargs['type'])

    @staticmethod
    def _replace_with_real_names(query_params):
        replaced_query_params = {}

        if not hasattr(query_params, 'attribute_map'):
            return query_params

        attribute_map = query_params.attribute_map

        if not isinstance(attribute_map, dict):
            return query_params

        query_params_dict = query_params.__dict__

        for k, v in iteritems(query_params_dict):
            new_key = attribute_map.get(k)
            if new_key is not None:
                replaced_query_params[new_key] = v

        return replaced_query_params



from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_api import LiveMediaIngestApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_output_list_query_params import LiveMediaIngestOutputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_export_task import AnalyticsExportTask
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.exports.analytics_export_task_list_query_params import AnalyticsExportTaskListQueryParams


class ExportsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ExportsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_export_task, **kwargs):
        # type: (AnalyticsExportTask, dict) -> AnalyticsExportTask
        """Create Export Task

        :param analytics_export_task: The export task to be created
        :type analytics_export_task: AnalyticsExportTask, required
        :return: Analytics export task
        :rtype: AnalyticsExportTask
        """

        return self.api_client.post(
            '/analytics/exports',
            analytics_export_task,
            type=AnalyticsExportTask,
            **kwargs
        )

    def get(self, export_task_id, **kwargs):
        # type: (string_types, dict) -> AnalyticsExportTask
        """Get export task

        :param export_task_id: Export task id
        :type export_task_id: string_types, required
        :return: Analytics export task
        :rtype: AnalyticsExportTask
        """

        return self.api_client.get(
            '/analytics/exports/{export_task_id}',
            path_params={'export_task_id': export_task_id},
            type=AnalyticsExportTask,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsExportTaskListQueryParams, dict) -> AnalyticsExportTask
        """List Export Tasks

        :param query_params: Query parameters
        :type query_params: AnalyticsExportTaskListQueryParams
        :return: Service specific result
        :rtype: AnalyticsExportTask
        """

        return self.api_client.get(
            '/analytics/exports',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsExportTask,
            **kwargs
        )



from bitmovin_api_sdk.notifications.notifications_api import NotificationsApi
from bitmovin_api_sdk.notifications.webhooks.webhooks_api import WebhooksApi
from bitmovin_api_sdk.notifications.states.states_api import StatesApi
from bitmovin_api_sdk.notifications.emails.emails_api import EmailsApi
from bitmovin_api_sdk.notifications.notification_list_query_params import NotificationListQueryParams
from bitmovin_api_sdk.notifications.notification_state_entry_list_by_notification_id_query_params import NotificationStateEntryListByNotificationIdQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.manifests.hls.media.custom_tags.custom_tags_api import CustomTagsApi
from bitmovin_api_sdk.encoding.manifests.hls.media.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.hls.media.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.hls.media.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.hls.media.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.manifests.hls.media.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.hls.media.closed_captions.closed_captions_api import ClosedCaptionsApi


class MediaApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(MediaApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.custom_tags = CustomTagsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.video = VideoApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio = AudioApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.subtitles = SubtitlesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vtt = VttApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.closed_captions = ClosedCaptionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
from bitmovin_api_sdk.encoding.infrastructure.aws.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.aws.aws_account_list_query_params import AwsAccountListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AclPermission(Enum):
    PUBLIC_READ = "PUBLIC_READ"
    PRIVATE = "PRIVATE"



from bitmovin_api_sdk.encoding.encodings.muxings.text.text_api import TextApi
from bitmovin_api_sdk.encoding.encodings.muxings.text.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.text.text_muxing_list_query_params import TextMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_atmos_dialogue_intelligence import DolbyAtmosDialogueIntelligence
from bitmovin_api_sdk.models.dolby_atmos_metering_mode import DolbyAtmosMeteringMode
import pprint
import six


class DolbyAtmosLoudnessControl(object):
    @poscheck_model
    def __init__(self,
                 metering_mode=None,
                 dialogue_intelligence=None,
                 speech_threshold=None):
        # type: (DolbyAtmosMeteringMode, DolbyAtmosDialogueIntelligence, int) -> None

        self._metering_mode = None
        self._dialogue_intelligence = None
        self._speech_threshold = None
        self.discriminator = None

        if metering_mode is not None:
            self.metering_mode = metering_mode
        if dialogue_intelligence is not None:
            self.dialogue_intelligence = dialogue_intelligence
        if speech_threshold is not None:
            self.speech_threshold = speech_threshold

    @property
    def openapi_types(self):
        types = {
            'metering_mode': 'DolbyAtmosMeteringMode',
            'dialogue_intelligence': 'DolbyAtmosDialogueIntelligence',
            'speech_threshold': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'metering_mode': 'meteringMode',
            'dialogue_intelligence': 'dialogueIntelligence',
            'speech_threshold': 'speechThreshold'
        }
        return attributes

    @property
    def metering_mode(self):
        # type: () -> DolbyAtmosMeteringMode
        """Gets the metering_mode of this DolbyAtmosLoudnessControl.

        Algorithm to be used for measuring loudness. Recommended value is \"ITU_R_BS_1770_4\" (required)

        :return: The metering_mode of this DolbyAtmosLoudnessControl.
        :rtype: DolbyAtmosMeteringMode
        """
        return self._metering_mode

    @metering_mode.setter
    def metering_mode(self, metering_mode):
        # type: (DolbyAtmosMeteringMode) -> None
        """Sets the metering_mode of this DolbyAtmosLoudnessControl.

        Algorithm to be used for measuring loudness. Recommended value is \"ITU_R_BS_1770_4\" (required)

        :param metering_mode: The metering_mode of this DolbyAtmosLoudnessControl.
        :type: DolbyAtmosMeteringMode
        """

        if metering_mode is not None:
            if not isinstance(metering_mode, DolbyAtmosMeteringMode):
                raise TypeError("Invalid type for `metering_mode`, type has to be `DolbyAtmosMeteringMode`")

        self._metering_mode = metering_mode

    @property
    def dialogue_intelligence(self):
        # type: () -> DolbyAtmosDialogueIntelligence
        """Gets the dialogue_intelligence of this DolbyAtmosLoudnessControl.

        Whether to use the Dialogue Intelligence feature, which identifies and analyzes dialogue segments within audio as a basis for speech gating. Must not be \"DISABLED\" for meteringMode \"ITU-R BS.1770-1\" or \"Leq (A)\", otherwise recommended value is \"ENABLED\" (required)

        :return: The dialogue_intelligence of this DolbyAtmosLoudnessControl.
        :rtype: DolbyAtmosDialogueIntelligence
        """
        return self._dialogue_intelligence

    @dialogue_intelligence.setter
    def dialogue_intelligence(self, dialogue_intelligence):
        # type: (DolbyAtmosDialogueIntelligence) -> None
        """Sets the dialogue_intelligence of this DolbyAtmosLoudnessControl.

        Whether to use the Dialogue Intelligence feature, which identifies and analyzes dialogue segments within audio as a basis for speech gating. Must not be \"DISABLED\" for meteringMode \"ITU-R BS.1770-1\" or \"Leq (A)\", otherwise recommended value is \"ENABLED\" (required)

        :param dialogue_intelligence: The dialogue_intelligence of this DolbyAtmosLoudnessControl.
        :type: DolbyAtmosDialogueIntelligence
        """

        if dialogue_intelligence is not None:
            if not isinstance(dialogue_intelligence, DolbyAtmosDialogueIntelligence):
                raise TypeError("Invalid type for `dialogue_intelligence`, type has to be `DolbyAtmosDialogueIntelligence`")

        self._dialogue_intelligence = dialogue_intelligence

    @property
    def speech_threshold(self):
        # type: () -> int
        """Gets the speech_threshold of this DolbyAtmosLoudnessControl.

        Specifies the percentage of speech that must be detected in the metered content before using the measured speech loudness as the overall program loudness. Given as an integer percentage between 0 and 100 (0% to 100%). Recommended value is 15 (required)

        :return: The speech_threshold of this DolbyAtmosLoudnessControl.
        :rtype: int
        """
        return self._speech_threshold

    @speech_threshold.setter
    def speech_threshold(self, speech_threshold):
        # type: (int) -> None
        """Sets the speech_threshold of this DolbyAtmosLoudnessControl.

        Specifies the percentage of speech that must be detected in the metered content before using the measured speech loudness as the overall program loudness. Given as an integer percentage between 0 and 100 (0% to 100%). Recommended value is 15 (required)

        :param speech_threshold: The speech_threshold of this DolbyAtmosLoudnessControl.
        :type: int
        """

        if speech_threshold is not None:
            if speech_threshold is not None and speech_threshold > 100:
                raise ValueError("Invalid value for `speech_threshold`, must be a value less than or equal to `100`")
            if speech_threshold is not None and speech_threshold < 0:
                raise ValueError("Invalid value for `speech_threshold`, must be a value greater than or equal to `0`")
            if not isinstance(speech_threshold, int):
                raise TypeError("Invalid type for `speech_threshold`, type has to be `int`")

        self._speech_threshold = speech_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyAtmosLoudnessControl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dash_manifest import DashManifest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.start_manifest_request import StartManifestRequest
from bitmovin_api_sdk.models.task import Task
from bitmovin_api_sdk.encoding.manifests.dash.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.dash.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.periods_api import PeriodsApi
from bitmovin_api_sdk.encoding.manifests.dash.dash_manifest_list_query_params import DashManifestListQueryParams


class DashApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DashApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.default = DefaultApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.periods = PeriodsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, dash_manifest, **kwargs):
        # type: (DashManifest, dict) -> DashManifest
        """Create DASH Manifest

        :param dash_manifest: The DASH manifest to be created
        :type dash_manifest: DashManifest, required
        :return: Id of the dash manifest
        :rtype: DashManifest
        """

        return self.api_client.post(
            '/encoding/manifests/dash',
            dash_manifest,
            type=DashManifest,
            **kwargs
        )

    def delete(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete DASH Manifest

        :param manifest_id: UUID of the DASH manifest to be deleted
        :type manifest_id: string_types, required
        :return: Id of the dash manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> DashManifest
        """DASH Manifest Details

        :param manifest_id: UUID of the dash manifest
        :type manifest_id: string_types, required
        :return: Dash Manifest details
        :rtype: DashManifest
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=DashManifest,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (DashManifestListQueryParams, dict) -> DashManifest
        """List DASH Manifests

        :param query_params: Query parameters
        :type query_params: DashManifestListQueryParams
        :return: List of dash manifests
        :rtype: DashManifest
        """

        return self.api_client.get(
            '/encoding/manifests/dash',
            query_params=query_params,
            pagination_response=True,
            type=DashManifest,
            **kwargs
        )

    def start(self, manifest_id, start_manifest_request=None, **kwargs):
        # type: (string_types, StartManifestRequest, dict) -> BitmovinResponse
        """Start DASH Manifest Creation

        :param manifest_id: Id of the DASH manifest.
        :type manifest_id: string_types, required
        :param start_manifest_request: Manifest Startup Options
        :type start_manifest_request: StartManifestRequest
        :return: Id of the manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/start',
            start_manifest_request,
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def status(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> Task
        """DASH Manifest Creation Status

        :param manifest_id: Id of the DASH manifest.
        :type manifest_id: string_types, required
        :return: Status of manifest creation
        :rtype: Task
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/status',
            path_params={'manifest_id': manifest_id},
            type=Task,
            **kwargs
        )

    def stop(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop DASH Manifest Creation

        :param manifest_id: Id of the DASH manifest.
        :type manifest_id: string_types, required
        :return: Id of the DASH manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/stop',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.configurations.audio.dtsx.dtsx_api import DtsxApi
from bitmovin_api_sdk.encoding.configurations.audio.dtsx.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dtsx.dts_x_audio_configuration_list_query_params import DtsXAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding_template import EncodingTemplate
from bitmovin_api_sdk.models.simple_encoding_vod_job_status import SimpleEncodingVodJobStatus
import pprint
import six


class SimpleEncodingVodJobResponse(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 status=None,
                 encoding_template=None,
                 encoding_id=None,
                 inputs=None,
                 outputs=None,
                 errors=None,
                 created_at=None,
                 modified_at=None,
                 name=None):
        # type: (string_types, SimpleEncodingVodJobStatus, EncodingTemplate, string_types, list[SimpleEncodingVodJobInput], list[SimpleEncodingVodJobOutput], list[SimpleEncodingVodJobErrors], datetime, datetime, string_types) -> None

        self._id = None
        self._status = None
        self._encoding_template = None
        self._encoding_id = None
        self._inputs = list()
        self._outputs = list()
        self._errors = list()
        self._created_at = None
        self._modified_at = None
        self._name = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if status is not None:
            self.status = status
        if encoding_template is not None:
            self.encoding_template = encoding_template
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs
        if errors is not None:
            self.errors = errors
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if name is not None:
            self.name = name

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'status': 'SimpleEncodingVodJobStatus',
            'encoding_template': 'EncodingTemplate',
            'encoding_id': 'string_types',
            'inputs': 'list[SimpleEncodingVodJobInput]',
            'outputs': 'list[SimpleEncodingVodJobOutput]',
            'errors': 'list[SimpleEncodingVodJobErrors]',
            'created_at': 'datetime',
            'modified_at': 'datetime',
            'name': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'status': 'status',
            'encoding_template': 'encodingTemplate',
            'encoding_id': 'encodingId',
            'inputs': 'inputs',
            'outputs': 'outputs',
            'errors': 'errors',
            'created_at': 'createdAt',
            'modified_at': 'modifiedAt',
            'name': 'name'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this SimpleEncodingVodJobResponse.

        The identifier of the Simple Encoding VOD Job

        :return: The id of this SimpleEncodingVodJobResponse.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this SimpleEncodingVodJobResponse.

        The identifier of the Simple Encoding VOD Job

        :param id_: The id of this SimpleEncodingVodJobResponse.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def status(self):
        # type: () -> SimpleEncodingVodJobStatus
        """Gets the status of this SimpleEncodingVodJobResponse.

        The current status of the Simple Encoding VOD Job

        :return: The status of this SimpleEncodingVodJobResponse.
        :rtype: SimpleEncodingVodJobStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (SimpleEncodingVodJobStatus) -> None
        """Sets the status of this SimpleEncodingVodJobResponse.

        The current status of the Simple Encoding VOD Job

        :param status: The status of this SimpleEncodingVodJobResponse.
        :type: SimpleEncodingVodJobStatus
        """

        if status is not None:
            if not isinstance(status, SimpleEncodingVodJobStatus):
                raise TypeError("Invalid type for `status`, type has to be `SimpleEncodingVodJobStatus`")

        self._status = status

    @property
    def encoding_template(self):
        # type: () -> EncodingTemplate
        """Gets the encoding_template of this SimpleEncodingVodJobResponse.

        The template that has been used for the encoding.

        :return: The encoding_template of this SimpleEncodingVodJobResponse.
        :rtype: EncodingTemplate
        """
        return self._encoding_template

    @encoding_template.setter
    def encoding_template(self, encoding_template):
        # type: (EncodingTemplate) -> None
        """Sets the encoding_template of this SimpleEncodingVodJobResponse.

        The template that has been used for the encoding.

        :param encoding_template: The encoding_template of this SimpleEncodingVodJobResponse.
        :type: EncodingTemplate
        """

        if encoding_template is not None:
            if not isinstance(encoding_template, EncodingTemplate):
                raise TypeError("Invalid type for `encoding_template`, type has to be `EncodingTemplate`")

        self._encoding_template = encoding_template

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this SimpleEncodingVodJobResponse.

        The identifier of the encoding that has been created based on the job request. This is only returned once the job execution has been successful and the encoding could be started. 

        :return: The encoding_id of this SimpleEncodingVodJobResponse.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this SimpleEncodingVodJobResponse.

        The identifier of the encoding that has been created based on the job request. This is only returned once the job execution has been successful and the encoding could be started. 

        :param encoding_id: The encoding_id of this SimpleEncodingVodJobResponse.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def inputs(self):
        # type: () -> list[SimpleEncodingVodJobInput]
        """Gets the inputs of this SimpleEncodingVodJobResponse.


        :return: The inputs of this SimpleEncodingVodJobResponse.
        :rtype: list[SimpleEncodingVodJobInput]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        # type: (list) -> None
        """Sets the inputs of this SimpleEncodingVodJobResponse.


        :param inputs: The inputs of this SimpleEncodingVodJobResponse.
        :type: list[SimpleEncodingVodJobInput]
        """

        if inputs is not None:
            if not isinstance(inputs, list):
                raise TypeError("Invalid type for `inputs`, type has to be `list[SimpleEncodingVodJobInput]`")

        self._inputs = inputs

    @property
    def outputs(self):
        # type: () -> list[SimpleEncodingVodJobOutput]
        """Gets the outputs of this SimpleEncodingVodJobResponse.


        :return: The outputs of this SimpleEncodingVodJobResponse.
        :rtype: list[SimpleEncodingVodJobOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this SimpleEncodingVodJobResponse.


        :param outputs: The outputs of this SimpleEncodingVodJobResponse.
        :type: list[SimpleEncodingVodJobOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[SimpleEncodingVodJobOutput]`")

        self._outputs = outputs

    @property
    def errors(self):
        # type: () -> list[SimpleEncodingVodJobErrors]
        """Gets the errors of this SimpleEncodingVodJobResponse.

        Describes all the errors in cases the status of the job is 'error'. 

        :return: The errors of this SimpleEncodingVodJobResponse.
        :rtype: list[SimpleEncodingVodJobErrors]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        # type: (list) -> None
        """Sets the errors of this SimpleEncodingVodJobResponse.

        Describes all the errors in cases the status of the job is 'error'. 

        :param errors: The errors of this SimpleEncodingVodJobResponse.
        :type: list[SimpleEncodingVodJobErrors]
        """

        if errors is not None:
            if not isinstance(errors, list):
                raise TypeError("Invalid type for `errors`, type has to be `list[SimpleEncodingVodJobErrors]`")

        self._errors = errors

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this SimpleEncodingVodJobResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this SimpleEncodingVodJobResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this SimpleEncodingVodJobResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this SimpleEncodingVodJobResponse.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def modified_at(self):
        # type: () -> datetime
        """Gets the modified_at of this SimpleEncodingVodJobResponse.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ. The job is updated for example when the status changes

        :return: The modified_at of this SimpleEncodingVodJobResponse.
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        # type: (datetime) -> None
        """Sets the modified_at of this SimpleEncodingVodJobResponse.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ. The job is updated for example when the status changes

        :param modified_at: The modified_at of this SimpleEncodingVodJobResponse.
        :type: datetime
        """

        if modified_at is not None:
            if not isinstance(modified_at, datetime):
                raise TypeError("Invalid type for `modified_at`, type has to be `datetime`")

        self._modified_at = modified_at

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this SimpleEncodingVodJobResponse.

        This property will be used for naming the encoding and the manifests.

        :return: The name of this SimpleEncodingVodJobResponse.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this SimpleEncodingVodJobResponse.

        This property will be used for naming the encoding and the manifests.

        :param name: The name of this SimpleEncodingVodJobResponse.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_live_cloud_region import SimpleEncodingLiveCloudRegion
from bitmovin_api_sdk.models.simple_encoding_live_job_input import SimpleEncodingLiveJobInput
from bitmovin_api_sdk.models.simple_encoding_live_profile import SimpleEncodingLiveProfile
import pprint
import six


class SimpleEncodingLiveJobRequest(object):
    @poscheck_model
    def __init__(self,
                 encoding_profile=None,
                 input_=None,
                 outputs=None,
                 cloud_region=None,
                 name=None):
        # type: (SimpleEncodingLiveProfile, SimpleEncodingLiveJobInput, list[SimpleEncodingLiveJobOutput], SimpleEncodingLiveCloudRegion, string_types) -> None

        self._encoding_profile = None
        self._input = None
        self._outputs = list()
        self._cloud_region = None
        self._name = None
        self.discriminator = None

        if encoding_profile is not None:
            self.encoding_profile = encoding_profile
        if input_ is not None:
            self.input = input_
        if outputs is not None:
            self.outputs = outputs
        if cloud_region is not None:
            self.cloud_region = cloud_region
        if name is not None:
            self.name = name

    @property
    def openapi_types(self):
        types = {
            'encoding_profile': 'SimpleEncodingLiveProfile',
            'input': 'SimpleEncodingLiveJobInput',
            'outputs': 'list[SimpleEncodingLiveJobOutput]',
            'cloud_region': 'SimpleEncodingLiveCloudRegion',
            'name': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'encoding_profile': 'encodingProfile',
            'input': 'input',
            'outputs': 'outputs',
            'cloud_region': 'cloudRegion',
            'name': 'name'
        }
        return attributes

    @property
    def encoding_profile(self):
        # type: () -> SimpleEncodingLiveProfile
        """Gets the encoding_profile of this SimpleEncodingLiveJobRequest.

        The profile that will be used for the live encoding.

        :return: The encoding_profile of this SimpleEncodingLiveJobRequest.
        :rtype: SimpleEncodingLiveProfile
        """
        return self._encoding_profile

    @encoding_profile.setter
    def encoding_profile(self, encoding_profile):
        # type: (SimpleEncodingLiveProfile) -> None
        """Sets the encoding_profile of this SimpleEncodingLiveJobRequest.

        The profile that will be used for the live encoding.

        :param encoding_profile: The encoding_profile of this SimpleEncodingLiveJobRequest.
        :type: SimpleEncodingLiveProfile
        """

        if encoding_profile is not None:
            if not isinstance(encoding_profile, SimpleEncodingLiveProfile):
                raise TypeError("Invalid type for `encoding_profile`, type has to be `SimpleEncodingLiveProfile`")

        self._encoding_profile = encoding_profile

    @property
    def input(self):
        # type: () -> SimpleEncodingLiveJobInput
        """Gets the input of this SimpleEncodingLiveJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api-live#inputs) (required)

        :return: The input of this SimpleEncodingLiveJobRequest.
        :rtype: SimpleEncodingLiveJobInput
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (SimpleEncodingLiveJobInput) -> None
        """Sets the input of this SimpleEncodingLiveJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api-live#inputs) (required)

        :param input_: The input of this SimpleEncodingLiveJobRequest.
        :type: SimpleEncodingLiveJobInput
        """

        if input_ is not None:
            if not isinstance(input_, SimpleEncodingLiveJobInput):
                raise TypeError("Invalid type for `input`, type has to be `SimpleEncodingLiveJobInput`")

        self._input = input_

    @property
    def outputs(self):
        # type: () -> list[SimpleEncodingLiveJobOutput]
        """Gets the outputs of this SimpleEncodingLiveJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api-live#outputs) (required)

        :return: The outputs of this SimpleEncodingLiveJobRequest.
        :rtype: list[SimpleEncodingLiveJobOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this SimpleEncodingLiveJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api-live#outputs) (required)

        :param outputs: The outputs of this SimpleEncodingLiveJobRequest.
        :type: list[SimpleEncodingLiveJobOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[SimpleEncodingLiveJobOutput]`")

        self._outputs = outputs

    @property
    def cloud_region(self):
        # type: () -> SimpleEncodingLiveCloudRegion
        """Gets the cloud_region of this SimpleEncodingLiveJobRequest.

        The cloud region that will be used for the live encoding. This value has to be set.

        :return: The cloud_region of this SimpleEncodingLiveJobRequest.
        :rtype: SimpleEncodingLiveCloudRegion
        """
        return self._cloud_region

    @cloud_region.setter
    def cloud_region(self, cloud_region):
        # type: (SimpleEncodingLiveCloudRegion) -> None
        """Sets the cloud_region of this SimpleEncodingLiveJobRequest.

        The cloud region that will be used for the live encoding. This value has to be set.

        :param cloud_region: The cloud_region of this SimpleEncodingLiveJobRequest.
        :type: SimpleEncodingLiveCloudRegion
        """

        if cloud_region is not None:
            if not isinstance(cloud_region, SimpleEncodingLiveCloudRegion):
                raise TypeError("Invalid type for `cloud_region`, type has to be `SimpleEncodingLiveCloudRegion`")

        self._cloud_region = cloud_region

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this SimpleEncodingLiveJobRequest.

        This property will be used for naming the encoding.

        :return: The name of this SimpleEncodingLiveJobRequest.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this SimpleEncodingLiveJobRequest.

        This property will be used for naming the encoding.

        :param name: The name of this SimpleEncodingLiveJobRequest.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingLiveJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.video.vp8.vp8_api import Vp8Api
from bitmovin_api_sdk.encoding.configurations.video.vp8.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.vp8.vp8_video_configuration_list_query_params import Vp8VideoConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.retry_hint import RetryHint
import pprint
import six


class ErrorDetails(object):
    @poscheck_model
    def __init__(self,
                 code=None,
                 category=None,
                 text=None,
                 retry_hint=None):
        # type: (int, string_types, string_types, RetryHint) -> None

        self._code = None
        self._category = None
        self._text = None
        self._retry_hint = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if category is not None:
            self.category = category
        if text is not None:
            self.text = text
        if retry_hint is not None:
            self.retry_hint = retry_hint

    @property
    def openapi_types(self):
        types = {
            'code': 'int',
            'category': 'string_types',
            'text': 'string_types',
            'retry_hint': 'RetryHint'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'code': 'code',
            'category': 'category',
            'text': 'text',
            'retry_hint': 'retryHint'
        }
        return attributes

    @property
    def code(self):
        # type: () -> int
        """Gets the code of this ErrorDetails.

        Specific error code (required)

        :return: The code of this ErrorDetails.
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        # type: (int) -> None
        """Sets the code of this ErrorDetails.

        Specific error code (required)

        :param code: The code of this ErrorDetails.
        :type: int
        """

        if code is not None:
            if not isinstance(code, int):
                raise TypeError("Invalid type for `code`, type has to be `int`")

        self._code = code

    @property
    def category(self):
        # type: () -> string_types
        """Gets the category of this ErrorDetails.

        Error group name (required)

        :return: The category of this ErrorDetails.
        :rtype: string_types
        """
        return self._category

    @category.setter
    def category(self, category):
        # type: (string_types) -> None
        """Sets the category of this ErrorDetails.

        Error group name (required)

        :param category: The category of this ErrorDetails.
        :type: string_types
        """

        if category is not None:
            if not isinstance(category, string_types):
                raise TypeError("Invalid type for `category`, type has to be `string_types`")

        self._category = category

    @property
    def text(self):
        # type: () -> string_types
        """Gets the text of this ErrorDetails.

        Detailed error message (required)

        :return: The text of this ErrorDetails.
        :rtype: string_types
        """
        return self._text

    @text.setter
    def text(self, text):
        # type: (string_types) -> None
        """Sets the text of this ErrorDetails.

        Detailed error message (required)

        :param text: The text of this ErrorDetails.
        :type: string_types
        """

        if text is not None:
            if not isinstance(text, string_types):
                raise TypeError("Invalid type for `text`, type has to be `string_types`")

        self._text = text

    @property
    def retry_hint(self):
        # type: () -> RetryHint
        """Gets the retry_hint of this ErrorDetails.

        Information if the encoding could potentially succeed when retrying. (required)

        :return: The retry_hint of this ErrorDetails.
        :rtype: RetryHint
        """
        return self._retry_hint

    @retry_hint.setter
    def retry_hint(self, retry_hint):
        # type: (RetryHint) -> None
        """Sets the retry_hint of this ErrorDetails.

        Information if the encoding could potentially succeed when retrying. (required)

        :param retry_hint: The retry_hint of this ErrorDetails.
        :type: RetryHint
        """

        if retry_hint is not None:
            if not isinstance(retry_hint, RetryHint):
                raise TypeError("Invalid type for `retry_hint`, type has to be `RetryHint`")

        self._retry_hint = retry_hint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class CdnUsageStatistics(object):
    @poscheck_model
    def __init__(self,
                 from_=None,
                 to=None,
                 storage_usage_total=None,
                 transfer_usage_total=None,
                 usage=None):
        # type: (datetime, datetime, float, float, list[CdnUsage]) -> None

        self._from_ = None
        self._to = None
        self._storage_usage_total = None
        self._transfer_usage_total = None
        self._usage = list()
        self.discriminator = None

        if from_ is not None:
            self.from_ = from_
        if to is not None:
            self.to = to
        if storage_usage_total is not None:
            self.storage_usage_total = storage_usage_total
        if transfer_usage_total is not None:
            self.transfer_usage_total = transfer_usage_total
        if usage is not None:
            self.usage = usage

    @property
    def openapi_types(self):
        types = {
            'from_': 'datetime',
            'to': 'datetime',
            'storage_usage_total': 'float',
            'transfer_usage_total': 'float',
            'usage': 'list[CdnUsage]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'from_': 'from',
            'to': 'to',
            'storage_usage_total': 'storageUsageTotal',
            'transfer_usage_total': 'transferUsageTotal',
            'usage': 'usage'
        }
        return attributes

    @property
    def from_(self):
        # type: () -> datetime
        """Gets the from_ of this CdnUsageStatistics.

        UTC timestamp which marks the beginning of the time period for which the usage statistics are retrieved.

        :return: The from_ of this CdnUsageStatistics.
        :rtype: datetime
        """
        return self._from_

    @from_.setter
    def from_(self, from_):
        # type: (datetime) -> None
        """Sets the from_ of this CdnUsageStatistics.

        UTC timestamp which marks the beginning of the time period for which the usage statistics are retrieved.

        :param from_: The from_ of this CdnUsageStatistics.
        :type: datetime
        """

        if from_ is not None:
            if not isinstance(from_, datetime):
                raise TypeError("Invalid type for `from_`, type has to be `datetime`")

        self._from_ = from_

    @property
    def to(self):
        # type: () -> datetime
        """Gets the to of this CdnUsageStatistics.

        UTC timestamp which marks the end of the time period for which the usage statistics are retrieved. The end date is exclusive. For example, if end is 2019-03-28T13:05:00Z, the cost and usage data are retrieved from the start date up to, but not including, 2019-03-28T13:05:00Z.

        :return: The to of this CdnUsageStatistics.
        :rtype: datetime
        """
        return self._to

    @to.setter
    def to(self, to):
        # type: (datetime) -> None
        """Sets the to of this CdnUsageStatistics.

        UTC timestamp which marks the end of the time period for which the usage statistics are retrieved. The end date is exclusive. For example, if end is 2019-03-28T13:05:00Z, the cost and usage data are retrieved from the start date up to, but not including, 2019-03-28T13:05:00Z.

        :param to: The to of this CdnUsageStatistics.
        :type: datetime
        """

        if to is not None:
            if not isinstance(to, datetime):
                raise TypeError("Invalid type for `to`, type has to be `datetime`")

        self._to = to

    @property
    def storage_usage_total(self):
        # type: () -> float
        """Gets the storage_usage_total of this CdnUsageStatistics.

        Total storage usage in GB per month.

        :return: The storage_usage_total of this CdnUsageStatistics.
        :rtype: float
        """
        return self._storage_usage_total

    @storage_usage_total.setter
    def storage_usage_total(self, storage_usage_total):
        # type: (float) -> None
        """Sets the storage_usage_total of this CdnUsageStatistics.

        Total storage usage in GB per month.

        :param storage_usage_total: The storage_usage_total of this CdnUsageStatistics.
        :type: float
        """

        if storage_usage_total is not None:
            if not isinstance(storage_usage_total, (float, int)):
                raise TypeError("Invalid type for `storage_usage_total`, type has to be `float`")

        self._storage_usage_total = storage_usage_total

    @property
    def transfer_usage_total(self):
        # type: () -> float
        """Gets the transfer_usage_total of this CdnUsageStatistics.

        Total transfer usage in GB.

        :return: The transfer_usage_total of this CdnUsageStatistics.
        :rtype: float
        """
        return self._transfer_usage_total

    @transfer_usage_total.setter
    def transfer_usage_total(self, transfer_usage_total):
        # type: (float) -> None
        """Sets the transfer_usage_total of this CdnUsageStatistics.

        Total transfer usage in GB.

        :param transfer_usage_total: The transfer_usage_total of this CdnUsageStatistics.
        :type: float
        """

        if transfer_usage_total is not None:
            if not isinstance(transfer_usage_total, (float, int)):
                raise TypeError("Invalid type for `transfer_usage_total`, type has to be `float`")

        self._transfer_usage_total = transfer_usage_total

    @property
    def usage(self):
        # type: () -> list[CdnUsage]
        """Gets the usage of this CdnUsageStatistics.


        :return: The usage of this CdnUsageStatistics.
        :rtype: list[CdnUsage]
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        # type: (list) -> None
        """Sets the usage of this CdnUsageStatistics.


        :param usage: The usage of this CdnUsageStatistics.
        :type: list[CdnUsage]
        """

        if usage is not None:
            if not isinstance(usage, list):
                raise TypeError("Invalid type for `usage`, type has to be `list[CdnUsage]`")

        self._usage = usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CdnUsageStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.encoding.inputs.inputs_api import InputsApi
from bitmovin_api_sdk.encoding.outputs.outputs_api import OutputsApi
from bitmovin_api_sdk.encoding.configurations.configurations_api import ConfigurationsApi
from bitmovin_api_sdk.encoding.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.manifests.manifests_api import ManifestsApi
from bitmovin_api_sdk.encoding.infrastructure.infrastructure_api import InfrastructureApi
from bitmovin_api_sdk.encoding.statistics.statistics_api import StatisticsApi
from bitmovin_api_sdk.encoding.watch_folders.watch_folders_api import WatchFoldersApi
from bitmovin_api_sdk.encoding.simple.simple_api import SimpleApi
from bitmovin_api_sdk.encoding.error_definitions.error_definitions_api import ErrorDefinitionsApi


class EncodingApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.inputs = InputsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.outputs = OutputsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.configurations = ConfigurationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.filters = FiltersApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.encodings = EncodingsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.manifests = ManifestsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.infrastructure = InfrastructureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.statistics = StatisticsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.watch_folders = WatchFoldersApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.simple = SimpleApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.error_definitions = ErrorDefinitionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )
